==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Tux/Resources/translations/Tux_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Sélectionner</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Pivoter</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Panoramique</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Inclinaison</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Style de navigation</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Touche clavier Page haut ou Page bas.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Focus de rotation</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Bouton central de la souris.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Style de navigation non reconnu.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Réglages</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Style d'orbite</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compact</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Infobulle</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Table tournante</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Non défini</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or H key.</source>
      <translation>Bouton central de la souris ou touche H.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Tux/Resources/translations/Tux_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="fr" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="NavigationIndicatorGui.py" line="63"/>
      <source>Select</source>
      <translation>Sélectionner</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="64"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="65"/>
      <source>Rotate</source>
      <translation>Pivoter</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="66"/>
      <source>Pan</source>
      <translation>Panoramique</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="67"/>
      <source>Tilt</source>
      <translation>Inclinaison</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="68"/>
      <source>Navigation style</source>
      <translation>Style de navigation</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="69"/>
      <source>Page Up or Page Down key.</source>
      <translation>Touche clavier Page haut ou Page bas.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="70"/>
      <source>Rotation focus</source>
      <translation>Focus de rotation</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="73"/>
      <source>Middle mouse button.</source>
      <translation>Bouton central de la souris.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="76"/>
      <source>Navigation style not recognized.</source>
      <translation>Style de navigation non reconnu.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Réglages</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Style d'orbite</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compact</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Infobulle</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Table tournante</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Non défini</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button or H key.</source>
      <translation>Bouton central de la souris ou touche H.</translation>
    </message>
  </context>
</TS>
